@@ -119,7 +119,7 @@ QWidget* KGameDialog::addConfigPage(KGameDialogConfig* widget, const QString& ti
  }
  QWidget* page = new QWidget();
  QVBoxLayout *pageVBoxLayout = new QVBoxLayout(page);
- pageVBoxLayout->setMargin(0);
+ pageVBoxLayout->setContentsMargins(0, 0, 0, 0);
  pageVBoxLayout->addWidget(widget);
  addPage(page,title);
  addConfigWidget(widget, page);
@@ -194,7 +194,7 @@ void KGameDialog::setOwner(KPlayer* owner)
 void KGameDialog::setKGame(KGame* g)
 {
  if (d->mGame) {
-	disconnect(d->mGame, 0, this, 0);
+	disconnect(d->mGame, nullptr, this, nullptr);
  }
  d->mGame = g;
  for (int i = 0; i < d->mConfigWidgets.count(); i++) {
